@@ -51,6 +51,40 @@ Concretlty, it's such as simple as that::
 from constants_and_vars import STATS
 import unicode_csv
 
+def get_line_from_table(csv_file, value, column, separator=',', quote='"', header=True):
+    """Search for an equivalence between value from column ``col_referer``
+    and ``value`` value, and return value from column ``col_return`` index at
+    the same line as matching pair ``col_referer`` values.
+
+    :param csv_file: The name of the CSV file to search into 
+    :type csv_file: str
+    :param value: The value to test
+    :type value: type
+    :param col_referer: The number of the column to compare to ``value``
+    :type col_referer: int
+    :param col_return: he number of the column to return if matches
+    :type col_return: int
+    :param separator: The CSV separator
+    :type separator: str
+    :param quote: The CSV quote
+    :type quote: str
+    :param header: CSV file has header
+    :type header: bool
+    :returns: list
+
+    """
+
+    res = []
+    with open(csv_file, 'r') as f:
+        filereader = unicode_csv.Reader(f, delimiter=separator, quotechar=quote)
+        for line in filereader:
+            if header:
+                header = False
+                continue
+            if line[column] == value:
+                res.append(line)
+    
+    return res
 
 def search_table(csv_file, value, col_referer=0, col_return=1, 
         separator=',', quote='"', header=True):
@@ -180,7 +214,7 @@ def get_id(model, fields, op='&'):
     :returns: int
 
     """
-    def _get_id(*args): 
+    def _get_id(*args):
         res = get_ids(model, fields, op)(*args)
         return res and res[0] or False
     
@@ -256,12 +290,10 @@ def get_fields(model, fields, op='&'):
 
     return _get_fields
 
-def to_boolean(mode=None,
-        true_values=('O', 'Y', '1', 'o', 'y', 'true', 'True'),
-        false_values=('0', 'N', '2', 'n', 'false', 'False')):
+def to_boolean(true='1', false='0', none=''):
     """Return a boolean depending from the input value.
     
-    >>> 'field': Column(2, to_boolean())
+    >>> 'field': Column(2, to_boolean('Y', 'N', ''))
     
     :param mode: First char will be used if value is True and second if False
     :type mode: str
@@ -271,25 +303,14 @@ def to_boolean(mode=None,
     :type false_values: str
     :returns: bool (or str)
 
-    True values::
-
-        'O', 'Y', '1', 'o', 'y', 'true', 'True'
-
-    False values::
-
-        '0', 'N', '2', 'n', 'false', 'False'
-
     """
     def _to_boolean(self, model, field, value, line):
-        if mode:
-            true = mode[0]
-            false = mode[1]
-        else:
-            true = True
-            false = False
-        return (value in true_values and true)\
-                or (value in false_values and false)\
-                or (value and true or false)
+        if value == str(true):
+            return True
+        elif value == str(false):
+            return False
+        elif value == str(none):
+            return None
 
     return _to_boolean
 
@@ -317,9 +338,12 @@ def to_date():
 def city_cedex(res=None, cedex_code=False):
     """Check if a cedex code is in the town name.
     Return the relative string to ``res`` argument
-
+    
+    from 'Paris Cedex 9'
     >>> 'city':  Column(6, city_cedex('city'))
+    'PARIS'
     >>> 'cedex': Column(6, city_cedex('cedex'))
+    'CEDEX 9'
     
     :param res: Relative string returned
     :type res: str
@@ -329,8 +353,7 @@ def city_cedex(res=None, cedex_code=False):
 
     """
     def _city_cedex(self, model, field, value, line):
-        string = value
-        string.upper()
+        string = value.upper()
         cedex = ""
 
         if string.count('CEDEX'):
